Function Main() {
    $GlobalAdmin = '##Automation--GlobalAdmin--##'
    $GlobalAdminPassword = '##Automation--GlobalAdminPassword--##'
    $ServiceAccounts = @(##Automation--ServiceAccounts--##)

    $old_ErrorActionPreference = $ErrorActionPreference
    $ErrorActionPreference = "silentlycontinue"

    $SecurePassword = $GlobalAdminPassword | convertto-securestring -AsPlainText -Force
    $Cred = new-object -typename System.Management.Automation.PSCredential -argumentlist $GlobalAdmin, $SecurePassword

    $Session = New-PSSession -ConfigurationName "Microsoft.Exchange" -ConnectionUri https://outlook.office365.com/powershell-liveid/ -Credential $Cred -Authentication Basic -AllowRedirection

    $ImpersonationFailures = @()
    $ViewOnlyRecipientsFailures = @()

    $CheckSuccessful = $false

    if ($null -eq $Session) {
        echo "Connection failed. Check GlobalAdmin Account credentials or Session limit exceeded please close other sessions and try again"
    }

    else {
        Import-PSSession $Session -DisableNameChecking -AllowClobber -CommandName Get-Mailbox, Get-ManagementRoleAssignment | Out-Null

        $allUser = Get-Mailbox -ResultSize unlimited | Where-Object {($_.IsMailboxEnabled -eq 1) -and ($_.IsValid -eq 1) -and ($_.OriginatingServer -like "*.outlook.com") -and (-not ($_.Alias -like "DiscoverySearchMailbox*"))}

        $allRolePolicy = Get-ManagementRoleAssignment -GetEffectiveUsers

        foreach ($account in $ServiceAccounts) {
            $mbName = $allUser | Where-Object {$_.EmailAddresses -Contains 'SMTP:' + $account} | foreach {$_.Name}

            $impersonation = $false
            $view_only_recp = $false
            $allRolePolicy | Where-Object {$_.EffectiveUserName -eq $mbName} | foreach $_.Role {
                if ($_.Role -eq "ApplicationImpersonation") {
                    $impersonation = $true
                } elseif ($_.Role -eq "View-Only Recipients") {
                    $view_only_recp = $true
                }
            }

            if ($false -eq  $impersonation) {
               $ImpersonationFailures += $account
            }

            if ($false -eq $view_only_recp) {
               $ViewOnlyRecipientsFailures += $account
            }
        }

        Remove-PSSession $Session
        Get-PSSession | Remove-PSSession

        if (($ImpersonationFailures.Length -eq 0) -and ($ViewOnlyRecipientsFailures.Length -eq 0)) {
            $CheckSuccessful = $true
            echo "Check successful"
        }
        else {
            Write-Output "Application Impersonation Failures"$ImpersonationFailures
            Write-Output "View Only Recipients Failures"$ViewOnlyRecipientsFailures
        }
    }

    $ErrorActionPreference = $old_ErrorActionPreference
    return $CheckSuccessful
}